pub enum AsSliceError {
NotContiguous,
Null,
DtypeMismatch {
expecting: Dtype,
found: Dtype,
},
Exception(Exception),
}Expand description
Error associated with Array::try_as_slice()
Variants
NotContiguous
The array data is not contiguous in row-major order.
Null
The underlying data pointer is null.
This is likely because the array has not been evaluated yet.
DtypeMismatch
The output dtype does not match the data type of the array.
Exception(Exception)
Exception